//
//  ViewController.swift
//  AmpChromecastSample
//
//  Created by Lopez Valenciano, Miguel on 5/5/16.
//  Copyright © 2016 Akamai. All rights reserved.
//

import UIKit
import AmpCore
import AmpChromecast
import GoogleCast

let url = "https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/DesigningForGoogleCast.mp4"

class ViewController: UIViewController, PlayerEventObserver, AmpChromecastObserver {
    
    @IBOutlet weak var playerView: UIView!
    
    var ampPlayer: AmpPlayer!
    var ampPlayerManager: AmpPlayerManager!
    var ampChromecast: AmpChromecastManager!
    
    var coverView: UIView?

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
    }
    
    override func viewDidAppear(animated: Bool) {
        self.ampPlayer = AmpPlayer()
        self.ampPlayerManager = AmpPlayerManager(ampPlayer: ampPlayer, parentView: self.playerView, playerFrame: self.playerView.bounds)
        //        self.ampPlayer.enableLogs()
        
        // Register
        self.ampPlayer.registerObserver(self)
        
        // Instantiate the Chromecast Manager
        self.ampChromecast = AmpChromecastManager(ampPlayer: self.ampPlayer)
        // If you want to listen to `AmpChromecastObserver` events, register as an observer
        self.ampChromecast.registerObserver(self)
        
        self.ampPlayer.handleUrl(url)
        
        self.coverView = UIView(frame: self.playerView.bounds)
        self.coverView?.backgroundColor = UIColor.blueColor()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func chromecastButton() {
        self.ampChromecast.showDevicesMenu()
    }
    
    // MARK: PlayerEventObserver
    
    func onAmpBufferingStateChanged(ampPlayer: AmpPlayer) {
        print("onBufferingStateChanged: \(ampPlayer.bufferingState)")
        if (ampPlayer.bufferingState == BufferingState.Ready && self.ampChromecast.playbackState != PlaybackState.Playing) {
            print("BufferingState.Ready")
            ampPlayer.play()
        }
    }
    
    func onAmpDoubleTap(ampPlayerManager: AmpPlayerManager) {
        if (ampPlayer.playbackState == PlaybackState.Playing) {
            ampPlayer.pause()
        } else {
            ampPlayer.play()
        }
    }
    
    // MARK: AmpChromecastObserver
    
    func onChromecastDeviceConnected(manager: AmpChromecastManager, device: GCKDevice) {
        print("\(device.friendlyName)")
    }

}

